diff -pruN 0.5.2-1/.gitlab-ci.yml 0.5.3-1/.gitlab-ci.yml
--- 0.5.2-1/.gitlab-ci.yml	2024-07-09 18:44:29.000000000 +0000
+++ 0.5.3-1/.gitlab-ci.yml	2024-08-03 16:52:47.000000000 +0000
@@ -11,7 +11,7 @@ variables:
     gobject-introspection-devel
     gdk-pixbuf2-devel
     sqlite-devel
-    pygobject3-devel
+    python3-gobject-devel
     python3-devel
   DEPENDENCIES_ABI_CHECK:
     libabigail
diff -pruN 0.5.2-1/NEWS 0.5.3-1/NEWS
--- 0.5.2-1/NEWS	2024-07-09 18:44:29.000000000 +0000
+++ 0.5.3-1/NEWS	2024-08-03 16:52:47.000000000 +0000
@@ -1,5 +1,10 @@
 Major changes in version
 
+0.5.3
+-----
+- Automatically ignore read-only properties
+- Add support for GParamSpec which are GBytes
+
 0.5.2
 -----
 - Fix a mismatched g_mutex_init()/g_mutex_clear() which caused
diff -pruN 0.5.2-1/debian/changelog 0.5.3-1/debian/changelog
--- 0.5.2-1/debian/changelog	2024-07-09 21:32:21.000000000 +0000
+++ 0.5.3-1/debian/changelog	2024-08-07 18:52:35.000000000 +0000
@@ -1,3 +1,10 @@
+libgom (0.5.3-1) unstable; urgency=medium
+
+  * New upstream release
+  * deiban/libgom-1.0-0t64.symbols: Add new symbol
+
+ -- Jeremy Bícha <jbicha@ubuntu.com>  Wed, 07 Aug 2024 14:52:35 -0400
+
 libgom (0.5.2-1) unstable; urgency=medium
 
   * New upstream release
diff -pruN 0.5.2-1/debian/libgom-1.0-0t64.symbols 0.5.3-1/debian/libgom-1.0-0t64.symbols
--- 0.5.2-1/debian/libgom-1.0-0t64.symbols	2024-07-09 21:32:21.000000000 +0000
+++ 0.5.3-1/debian/libgom-1.0-0t64.symbols	2024-08-07 18:52:35.000000000 +0000
@@ -27,6 +27,7 @@ libgom-1.0.so.0 libgom-1.0-0t64 #MINVER#
  gom_command_get_type@Base 0.2.1
  gom_command_reset@Base 0.2.1
  gom_command_set_param@Base 0.2.1
+ gom_command_set_param_bytes@Base 0.5.3
  gom_command_set_param_double@Base 0.2.1
  gom_command_set_param_float@Base 0.2.1
  gom_command_set_param_int64@Base 0.2.1
diff -pruN 0.5.2-1/gom/gom-command-builder.c 0.5.3-1/gom/gom-command-builder.c
--- 0.5.2-1/gom/gom-command-builder.c	2024-07-09 18:44:29.000000000 +0000
+++ 0.5.3-1/gom/gom-command-builder.c	2024-08-03 16:52:47.000000000 +0000
@@ -83,6 +83,8 @@ sql_type_for_column (GParamSpec *pspec)
       if (parent_type == G_TYPE_ENUM ||
           parent_type == G_TYPE_FLAGS)
         return "INTEGER";
+      if (pspec->value_type == G_TYPE_BYTES)
+        return "BLOB";
       if (g_param_spec_get_qdata(pspec, GOM_RESOURCE_FROM_BYTES_FUNC) != NULL)
         return "BLOB";
 
@@ -101,6 +103,10 @@ is_mapped (GParamSpec *pspec)
    if (!ret)
      return FALSE;
 
+   /* Ignore read-only properties as we can never write them back */
+   if ((pspec->flags & G_PARAM_WRITABLE) == 0)
+     return FALSE;
+
    ret = (sql_type_for_column(pspec) != NULL);
    if (!ret) {
      g_debug("Property %s not mapped because type is unsupported (%s)",
diff -pruN 0.5.2-1/gom/gom-command.c 0.5.3-1/gom/gom-command.c
--- 0.5.2-1/gom/gom-command.c	2024-07-09 18:44:29.000000000 +0000
+++ 0.5.3-1/gom/gom-command.c	2024-08-03 16:52:47.000000000 +0000
@@ -249,6 +249,18 @@ SET_PARAM_HELPER(guint, uint, UINT)
 SET_PARAM_HELPER(guint64, uint64, UINT64)
 SET_PARAM_HELPER(const gchar *, string, STRING)
 
+void
+gom_command_set_param_bytes (GomCommand *command,
+                             guint       param,
+                             GBytes     *bytes)
+{
+  GValue gvalue = G_VALUE_INIT;
+  g_value_init (&gvalue, G_TYPE_BYTES);
+  g_value_set_boxed (&gvalue, bytes);
+  gom_command_set_param (command, param, &gvalue);
+  g_value_unset (&gvalue);
+}
+
 gint
 gom_command_get_param_index (GomCommand  *command,
                              const gchar *param_name)
diff -pruN 0.5.2-1/gom/gom-command.h 0.5.3-1/gom/gom-command.h
--- 0.5.2-1/gom/gom-command.h	2024-07-09 18:44:29.000000000 +0000
+++ 0.5.3-1/gom/gom-command.h	2024-08-03 16:52:47.000000000 +0000
@@ -83,6 +83,9 @@ void         gom_command_set_param_uint6
 void         gom_command_set_param_string (GomCommand    *command,
                                            guint          param,
                                            const gchar   *value);
+void         gom_command_set_param_bytes  (GomCommand    *command,
+                                           guint          param,
+                                           GBytes        *bytes);
 
 G_END_DECLS
 
diff -pruN 0.5.2-1/gom/gom-cursor.c 0.5.3-1/gom/gom-cursor.c
--- 0.5.2-1/gom/gom-cursor.c	2024-07-09 18:44:29.000000000 +0000
+++ 0.5.3-1/gom/gom-cursor.c	2024-08-03 16:52:47.000000000 +0000
@@ -149,6 +149,9 @@ gom_cursor_get_column (GomCursor *cursor
          g_value_take_boxed(value, g_bytes_new_take(data_copy, size));
          }
          break;
+      case SQLITE_NULL:
+         g_value_init(value, G_TYPE_BYTES);
+         break;
       default:
          g_assert_not_reached();
       }
diff -pruN 0.5.2-1/meson.build 0.5.3-1/meson.build
--- 0.5.2-1/meson.build	2024-07-09 18:44:29.000000000 +0000
+++ 0.5.3-1/meson.build	2024-08-03 16:52:47.000000000 +0000
@@ -1,5 +1,5 @@
 project('gom', 'c',
-  version: '0.5.2',
+  version: '0.5.3',
   license: 'LGPL-2.1+',
   meson_version: '>= 0.48')
 
